import { Toaster } from "@/components/ui/toaster";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { createBrowserRouter, RouterProvider, Navigate } from "react-router-dom";
import { HelmetProvider } from "react-helmet-async";
import { Suspense, lazy, useEffect, useState } from "react";
import { performanceMonitor } from './utils/performanceMonitor';
import { AnalyticsProvider } from './components/analytics/AnalyticsProvider';

// Lazy load components to reduce initial bundle size
const TitanSecureCampaignPages = lazy(() => import("./pages/titan-secure-campaign-pages"));
const NotFound = lazy(() => import("./pages/NotFound"));
const ThankYou = lazy(() => import("./pages/ThankYou"));
const BuyNow = lazy(() => import("./pages/BuyNow"));
const BookNow = lazy(() => import("./pages/BookNow"));
const CheckoutPage = lazy(() => import("./pages/checkout/CheckoutPage"));
const LocationTemplate = lazy(() => import("./components/templates/LocationTemplate"));
const AlbuquerquePillarPage = lazy(() => import("./pages/AlbuquerquePillarPage"));
const PhoenixPillarPage = lazy(() => import("./pages/PhoenixPillarPage"));
const TucsonPillarPage = lazy(() => import("./pages/TucsonPillarPage"));
const LasCrucesPillarPage = lazy(() => import("./pages/LasCrucesPillarPage"));
const DallasPillarPage = lazy(() => import("./pages/DallasPillarPage"));

// Trust-building pages - TEMPORARILY HIDDEN
// const IntegrationProcess = lazy(() => import("./pages/IntegrationProcess"));
// const Warranty = lazy(() => import("./pages/Warranty"));
// const Technicians = lazy(() => import("./pages/Technicians"));

const queryClient = new QueryClient();

// Loading component
const LoadingSpinner = () => (
  <div className="app-loading">
    <div className="spinner"></div>
  </div>
);

// Create router configuration
const router = createBrowserRouter([
  {
    path: "/",
    element: <TitanSecureCampaignPages />,
  },
  {
    path: "/thank-you",
    element: <ThankYou />,
  },
  {
    path: "/checkout/*",
    element: <CheckoutPage />,
  },
  {
    path: "/buy-now",
    element: <BuyNow />,
  },
  {
    path: "/book-now",
    element: <BookNow />,
  },
  {
    path: "/phoenix",
    element: <PhoenixPillarPage />,
  },
  {
    path: "/albuquerque",
    element: <AlbuquerquePillarPage />,
  },
  {
    path: "/tucson",
    element: <TucsonPillarPage />,
  },
  {
    path: "/lascruces",
    element: <LasCrucesPillarPage />,
  },
  {
    path: "/dallas",
    element: <DallasPillarPage />,
  },
  {
    path: "/campaigns",
    element: <Navigate to="/" replace={true} />,
  },
  {
    path: "/campaigns/phoenix",
    element: <Navigate to="/phoenix" replace={true} />,
  },
  {
    path: "/campaigns/albuquerque",
    element: <Navigate to="/albuquerque" replace={true} />,
  },
  {
    path: "/campaigns/tucson",
    element: <Navigate to="/tucson" replace={true} />,
  },
  {
    path: "/campaigns/lascruces",
    element: <Navigate to="/lascruces" replace={true} />,
  },
  {
    path: "/campaigns/dallas",
    element: <Navigate to="/dallas" replace={true} />,
  },
  {
    path: "/campaigns/phoenix-area",
    element: <Navigate to="/phoenix" replace={true} />,
  },
  {
    path: "/campaigns/albuquerque-area",
    element: <Navigate to="/albuquerque" replace={true} />,
  },
  {
    path: "/campaigns/tucson-area",
    element: <Navigate to="/tucson" replace={true} />,
  },
  {
    path: "/campaigns/las-cruces-area",
    element: <Navigate to="/lascruces" replace={true} />,
  },
  {
    path: "/campaigns/dallas-area",
    element: <Navigate to="/dallas" replace={true} />,
  },
  {
    path: "/:city/:district?",
    element: <LocationTemplate />,
  },
  {
    path: "*",
    element: <NotFound />,
  },
]);

/**
 * Main application component
 */
function App() {
  return (
    <HelmetProvider>
      <QueryClientProvider client={queryClient}>
        <AnalyticsProvider>
          <TooltipProvider>
            <Suspense fallback={<LoadingSpinner />}>
              <RouterProvider router={router} />
            </Suspense>
            <Toaster />
            <Sonner />
          </TooltipProvider>
        </AnalyticsProvider>
      </QueryClientProvider>
    </HelmetProvider>
  );
}

export default App;
